===========================================================
``psyclone.psyir.transformations.hoist_local_arrays_trans``
===========================================================

.. automodule:: psyclone.psyir.transformations.hoist_local_arrays_trans

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.transformations.hoist_local_arrays_trans


Classes
=======

- :py:class:`HoistLocalArraysTrans`:
  This transformation takes a Routine and promotes any local, 'automatic'


.. autoclass:: HoistLocalArraysTrans
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: HoistLocalArraysTrans
      :parts: 1
